@@ -15,6 +15,7 @@ import yaml
 import logging
 from pathlib import Path
 from collections.abc import MutableMapping
+import pprint
 
 from ploomber import products
 from ploomber import DAG, tasks
@@ -24,8 +25,10 @@ from ploomber.spec.TaskSpec import TaskSpec
 from ploomber.spec import validate
 from ploomber.dag.DAGConfiguration import DAGConfiguration
 from ploomber.exceptions import DAGSpecInitializationError
+from ploomber.env.expand import expand_raw_dictionary
 
 logger = logging.getLogger(__name__)
+pp = pprint.PrettyPrinter(indent=4)
 
 
 class DAGSpec(MutableMapping):
@@ -59,13 +62,21 @@ class DAGSpec(MutableMapping):
     to make sure they work. This is why we need to keep the pipeline.yaml
     location when initializing a DAG from a spec.
     """
-    def __init__(self, data):
+    def __init__(self, data, env=None):
         # only set when initialized from DAGSpec.from_file
         self._parent_path = None
 
         if isinstance(data, list):
             data = {'tasks': data}
 
+        logger.debug('DAGSpec enviroment:\n%s', pp.pformat(env))
+
+        # expand if there's an env.yaml file
+        if env is not None:
+            data = expand_raw_dictionary(data, env)
+
+        logger.debug('Expanded DAGSpec:\n%s', pp.pformat(data))
+
         load_from_factory = self._validate_top_level_keys(data)
         self.data = data
 
