@@ -1,8 +1,8 @@
 from ploomber.util.util import (safe_remove, image_bytes2html,
-                                clean_up_files, isiterable, path2fig,
+                                isiterable, path2fig,
                                 requires)
 from ploomber.util import markup
 from ploomber.util.param_grid import Interval, ParamGrid
 
-__all__ = ['safe_remove', 'image_bytes2html', 'clean_up_files', 'Interval',
+__all__ = ['safe_remove', 'image_bytes2html', 'Interval',
            'ParamGrid', 'isiterable', 'path2fig', 'requires', 'markup']
